package main

import (
	"io"
	"net/mail"

	"github.com/gin-gonic/gin"
	log "github.com/sirupsen/logrus"
	"github.com/tidwall/gjson"
)

func userSubscribe(c *gin.Context) {
	body, err := io.ReadAll(c.Request.Body)
	if err != nil {
		c.JSON(200, gin.H{"error": "request parameter error", "code": 1})
		return
	}
	email := gjson.Get(string(body), "email").String()
	if _, err = mail.ParseAddress(email); err != nil {
		c.JSON(200, gin.H{"error": "request parameter error", "code": 1})
		return
	}

	go func() {
		if err = sendSubscribeEmail(email); err != nil {
			log.WithField("email", email).Error("send subscribe email error", err.Error())
			return
		}
		log.WithField("email", email).Info("send subscribe email success")
	}()
	c.JSON(200, gin.H{"error": "", "code": 0})
}

func userContactUs(c *gin.Context) {
	body, err := io.ReadAll(c.Request.Body)
	if err != nil {
		c.JSON(200, gin.H{"error": "request parameter error", "code": 1})
		return
	}

	name := gjson.Get(string(body), "name").String()
	email := gjson.Get(string(body), "email").String()
	message := gjson.Get(string(body), "message").String()
	if len(name) == 0 || len(email) == 0 || len(message) == 0 {
		c.JSON(200, gin.H{"error": "request parameter error", "code": 1})
		return
	}

	if _, err = mail.ParseAddress(email); err != nil {
		c.JSON(200, gin.H{"error": "request parameter error", "code": 1})
		return
	}

	go func() {
		baseLog := log.WithFields(log.Fields{
			"email":   email,
			"name":    name,
			"message": message,
		})
		if err = sendContactEmail(name, email, message); err != nil {
			baseLog.Error("send contact us email error", err.Error())
			return
		}
		baseLog.Info("send contact us email success")
	}()
	c.JSON(200, gin.H{"error": "", "code": 0})
}
